@@ -10,17 +10,11 @@ from json import loads
 from dynaconf import settings as dynasettings
 
 from .aes_util import AESUtil
+from .exceptions import CadException
+from .log_util import LogUtil
 from .redis_util import RedisUtil
 
 
-class CadException(BaseException):
-    def __init__(self, ak):
-        self._msg = f'the ak: {ak} is not found'
-
-    def __str__(self):
-        return self._msg
-
-
 class CadUtil(object):
     def __init__(self, redis_url_str: str = None, key: str = None, cache_key: str = None):
         """
@@ -40,6 +34,7 @@ class CadUtil(object):
         self._redis_client = RedisUtil(url_str=redis_url_str).redis
         self._aes_client = AESUtil(encrypt_key=key)
 
+    @LogUtil()
     def get(self, ak: str) -> dict:
         """
         通过ak获取解密后的用户信息
