@@ -10,6 +10,18 @@ from redis import ConnectionPool, Redis
 
 
 class RedisUtil(object):
+    def __new__(cls, *args, **kwargs):
+        """
+        实现单例
+        :param args:
+        :param kwargs:
+        """
+        if not hasattr(cls, '_instance'):
+            cls._instance = super().__new__(cls)
+            return cls._instance
+        else:
+            return cls._instance
+
     def __init__(self, host: str = 'localhost', port: int = 6379, db: int = 0, password: str = '', url_str: str = None,
                  **kwargs):
         if url_str is not None:
